@@ -249,7 +249,7 @@ class EnclaveManifest:
     misc_mask: int  # 32-bits bitvector
 
     def __post_init__(self):
-        for (name, field_type) in self.__annotations__.items():
+        for name, field_type in self.__annotations__.items():
             if not isinstance(self.__dict__[name], field_type):
                 current_type = type(self.__dict__[name])
                 raise TypeError(
