@@ -14,7 +14,7 @@
 
 
 import pathlib
-from ._dcap_attestation import validate_attestation
+from ._dcap_attestation import validate_attestation, AttestationError
 from .utils import *
 
 from dataclasses import dataclass
@@ -36,6 +36,8 @@ import tempfile
 import requests
 from requests.adapters import HTTPAdapter
 from importlib_metadata import version
+import warnings
+
 
 app_version = version("blindai-preview")
 
@@ -43,6 +45,10 @@ app_version = version("blindai-preview")
 CONNECTION_TIMEOUT = 10
 
 
+class SimulationModeWarning(Warning):
+    pass
+
+
 class ModelDatumType(IntEnum):
     F32 = 0
     F64 = 1
@@ -480,6 +486,7 @@ class BlindAiConnection(contextlib.AbstractContextManager):
         attested_port: int,
         hazmat_manifest_path: Optional[pathlib.Path],
         hazmat_http_on_untrusted_port: bool,
+        simulation_mode: bool,
     ):
         """Connect to a BlindAi service.
 
@@ -491,9 +498,21 @@ class BlindAiConnection(contextlib.AbstractContextManager):
             attested_port (int):
             hazmat_manifest_path (Optional[pathlib.Path]):
             hazmat_http_on_untrusted_port (bool):
-
+            simulation_mode (bool):
         Returns:
         """
+
+        if simulation_mode:
+            warnings.warn(
+                (
+                    "BlindAI is running in simulation mode. "
+                    "This mode is provided solely for testing purposes. "
+                    "It does not provide any security since there is no SGX enclave. "
+                    "The simulation mode MUST NOT be used in production."
+                ),
+                SimulationModeWarning,
+            )
+
         # uname = platform.uname()
 
         # self.client_info = _ClientInfo(
@@ -531,14 +550,20 @@ class BlindAiConnection(contextlib.AbstractContextManager):
         # Always raise an exception when HTTP returns an error code for the untrusted connection
         # Note : we might want to do the same for the attested connection ?
         s.hooks = {"response": lambda r, *args, **kwargs: r.raise_for_status()}
+        req = s.get(self._untrusted_url)
+        cert = cbor.loads(req.content)
+        if not simulation_mode and "mock" in req.headers["Server"]:
+            raise AttestationError(
+                "The BlindAI server is a mock. You can only connect to it in simulation mode."
+            )
 
-        cert = cbor.loads(s.get(self._untrusted_url).content)
-        quote = cbor.loads(s.get(f"{self._untrusted_url}/quote").content)
-        collateral = cbor.loads(s.get(f"{self._untrusted_url}/collateral").content)
+        if not simulation_mode:
+            quote = cbor.loads(s.get(f"{self._untrusted_url}/quote").content)
+            collateral = cbor.loads(s.get(f"{self._untrusted_url}/collateral").content)
 
-        validate_attestation(
-            quote, collateral, cert, manifest_path=hazmat_manifest_path
-        )
+            validate_attestation(
+                quote, collateral, cert, manifest_path=hazmat_manifest_path
+            )
 
         # requests (http library) takes a path to a file containing the CA
         # there is no easy way to give the CA as a string/bytes directly
@@ -700,6 +725,7 @@ def connect(
     attested_port: int = 9924,
     hazmat_manifest_path: Optional[pathlib.Path] = None,
     hazmat_http_on_untrusted_port=False,
+    simulation_mode: bool = False,
 ) -> BlindAiConnection:
     """Connect to a BlindAi server.
 
@@ -717,6 +743,10 @@ def connect(
             the server using a plain HTTP connection instead of a more secure HTTPS connection. Defaults to False.
             Caution: This parameter should never be set to True in production. Using a HTTPS connection is critical to
             get a graceful degradation in case of a failure of the Intel SGX attestation.
+        simulation_mode (bool, optional): If set to True, BlindAI will work in simulation mode.
+            Caution: In simulation, BlindAI does not provide any security since there is no SGX enclave.
+            This mode SHOULD NEVER be enabled in production.
+            Defaults to False (production mode)
 
      Raises:
         requests.exceptions.RequestException: If a network or server error occurs
@@ -736,4 +766,5 @@ def connect(
         attested_port,
         hazmat_manifest_path,
         hazmat_http_on_untrusted_port,
+        simulation_mode,
     )
